---
title: v3.1.0 (latest)
sidebar_position: 0
---
## Breaking changes
- `Client.stop_listening` is now an async function, so you must await it if you're calling it on your code. If you don't use stop_listening, there is no breaking changes for you.

## Highlights of this release
- `register_next_step_handler` is finally here!
A lot of people that asks for conversation handling on Pyrogram (and don't know pyromod yet) actually wants something [like pyTelegramBotApi does](https://github.com/eternnoir/pyTelegramBotAPI/blob/a3343fc59a7839f76df6034f365e90018d374e55/examples/step_example.py#L24-L74) with `register_next_step_handler`. Well, finally you can use it in Pyrogram, with pyromod! And it's not based on Futures like `listen` and `ask` are, so those who don't like pyromod might like this new feature.

The difference from pyTelegramBotApi's approach is that with pyromod, your callback will actually receive the Client object and the received Message (or CallbackQuery). In pyTelegramBotApi, the callback receives only the Message. Also, you don't need to call any other function than `register_next_step_handler`. You just call it passing your callback and that's all! Check the example below:
<img src="https://github.com/usernein/pyromod/assets/29507335/52b8fc98-0633-49ab-8992-fa64c8a0e2d7" width="600" />
<img src="https://github.com/usernein/pyromod/assets/29507335/d60cf1b1-2b43-4a14-83eb-58f05a64ba13" width="500" />

- Now pyromod accepts lists of values for `chat_id`, `user_id`, `message_id` and `inline_message_id`.
<img src="https://github.com/usernein/pyromod/assets/29507335/79f88fab-ab15-4467-bacd-102202888cfc" width="500" />

- Now pyromod accepts usernames for `chat_id` and `user_id`, so the example above could also be:
<img src="https://github.com/usernein/pyromod/assets/29507335/b48c4c3a-e275-4b29-b80f-ba2512f146d4" width="500" />

## Other changes
- Thanks to @jusidama18 with #34, now pyromod will also work if you use sync filters.


**Full Changelog**: https://github.com/usernein/pyromod/compare/v3.0.0...v3.1.0